@@ -24,7 +24,9 @@ page](https://github.com/MarcvdSluys/Meteoserver).
 
 name = "meteoserver"
 
+from .uurverwachting import *
 from .zonactueel import *
+from .help import *
 
 
 
